==> flutter_jiopay_pg-0.0.2.tar.gz: ios/Classes/FlutterJiopayPgDelegate.swift <==
//
//  FlutterJiopayPgDelegate.swift
//  flutter_jiopay_pg_uat
//
//  Created by Harshit Agrawal on 23/03/22.
//

import Foundation
//
//  FlutterAppDelegate.swift
//  flutter_jiopay_pg_uat
//
//  Created by Harshit Agrawal on 23/03/22.
//

import Flutter
import Foundation
import Jiopay_pg

public class FlutterJiopayPgDelegate: NSObject ,JioPayDelegate  {
    public func onPaymentSuccess(tid: String, intentId: String) {
        print("sucess")
        var response = [String:Any]()
        response["type"] = 0
        var data = [String:Any]()
        data["tnxId"] = tid
        data["intentId"] = intentId
        response["data"] = data
        pendingResult(response as NSDictionary)
    }
    
    public func onPaymentError(code: String, error: String) {
        print("onPaymentError")
        var response = [String:Any]()
        response["type"] = 1
        var data = [String:Any]()
        data["code"] = code
        data["message"] = error
        response["data"] = data
        pendingResult(response as NSDictionary)
    }
        
        private var pendingResult: FlutterResult!
        
        public func open(options: [AnyHashable:Any], result: @escaping FlutterResult) {
           
            self.pendingResult = resul
            if let vc = UIApplication.shared.delegate?.window??.rootViewController  as? FlutterViewController {
                let pgWebView = JioPayPGViewController()
                pgWebView.open(vc, withData: options, delegate: self)
            }
        }
    public func resync(result: @escaping FlutterResult) {
         result(nil)
     }
     
       
        
}

==> flutter_jiopay_pg-0.0.5.tar.gz: ios/Classes/FlutterJiopayPgDelegate.swift <==
//
//  FlutterJiopayPgDelegate.swift
//  flutter_jiopay_pg_uat
//
//  Created by Harshit Agrawal on 23/03/22.
//

import Foundation
//
//  FlutterAppDelegate.swift
//  flutter_jiopay_pg_uat
//
//  Created by Harshit Agrawal on 23/03/22.
//

import Flutter
import Foundation
import Jiopay_pg

public class FlutterJiopayPgDelegate: NSObject ,JioPayDelegate  {
    public func onPaymentSuccess(tid: String, intentId: String) {
        print("sucess")
        var response = [String:Any]()
        response["type"] = 0
        var data = [String:Any]()
        data["tnxId"] = tid
        data["intentId"] = intentId
        response["data"] = data
        pendingResult(response as NSDictionary)
    }
    
    public func onPaymentError(code: String, error: String) {
        print("onPaymentError")
        var response = [String:Any]()
        response["type"] = 1
        var data = [String:Any]()
        data["code"] = code
        data["message"] = error
        response["data"] = data
        pendingResult(response as NSDictionary)
    }
        
        private var pendingResult: FlutterResult!
        
        public func open(options: [AnyHashable:Any], result: @escaping FlutterResult) {
           
            self.pendingResult = result
            if let vc = UIApplication.shared.delegate?.window??.rootViewController  as? FlutterViewController {
                let pgWebView = JioPayPGViewController()
                pgWebView.open(vc, withData: options, delegate: self)
            }
        }
    public func resync(result: @escaping FlutterResult) {
         result(nil)
     }
     
       
        
}
